; Chromium/theme.jl

(let*
  (
    (font-colors (list "Light Grey"
                       "Black"))
                       
    (title-width
      (lambda (w)
        (let
          ((w-width (car (window-dimensions w))))
        (max 0 (+ 20 (min (- w-width 74) (text-width (window-name w))))))))
        
    (half-title-width
       (lambda (w)
         (/ (title-width w) 2)))
         
    (title-position
       (lambda (w)
         (- (/ (car (window-dimensions w)) 2) (half-title-width w)) ))
          
    (update-title-width
      (lambda (w)
        (if (eq (window-get w 'current-frame-style) 'Chromium) 
          (rebuild-frame w))))
    
    (close-button-image (list (make-image "close.png")
                               nil nil
                              (make-image "close-click.png")))
    (maximize-button-image (list (make-image "maximize.png")
                                  nil nil
                                 (make-image "maximize-click.png")))
    (left-image (make-image "left.png"))
    (right-image (make-image "right.png"))
    (middle-image (make-image "middle.png"))
    (bevel-image (make-image "bevel.png"))
    (left-title-area (list (make-image "inactive-left.png")
                            (make-image "active-left.png") ))
    (middle-title-area (list (make-image "inactive-middle.png")
                              (make-image "active-middle.png") ))
    (right-title-area (list (make-image "inactive-right.png")
                             (make-image "active-right.png") ))

    (frame `(
        ((background . ,middle-image)
         (left-edge . 0)
         (right-edge . 0)
         (top-edge . -21)
         (class . title))
         
        ((background . ,bevel-image)
         (left-edge . ,20)
         (top-edge . -21)
         (class . title))
         
        ((background . ,bevel-image)
         (right-edge . ,20)
         (top-edge . -21)
         (class . title))
         
        ((background . ,left-title-area)
         (left-edge . ,(lambda (w) (- (title-position w) 8)))
         (top-edge . -19)
         (class . title))
         
        ((background . ,middle-title-area)
         (left-edge . ,(lambda (w) (title-position w)))
         (right-edge . ,(lambda (w) (title-position w)))
         (top-edge . -19)
         (foreground . ,font-colors)
         (text . ,window-name)
         (x-justify . center)
         (y-justify . center)
         (class . title))
         
        ((background . ,right-title-area)
         (right-edge . ,(lambda (w) (- (title-position w) 8)))
         (top-edge . -19)
         (class . title))
                
        ((background . ,close-button-image)
         (left-edge . 4)
         (top-edge . -17)
         (class . close-button))
         
        ((background . ,maximize-button-image)
         (right-edge . 4)
         (top-edge . -17)
         (class . maximize-button))
         
        ((background . ,left-image)
         (left-edge . -1)
         (top-edge . -21)
         (class . title))
                 
        ((background . ,right-image)
         (right-edge . -1)
         (top-edge . -21)
         (class . title))         
                 
        ((background . "Dark Grey")
         (left-edge . -1)
         (top-edge . 0)
         (bottom-edge . 0)
         (width . 1)
         (class . left-border))
         
        ((background . "Dark Grey")
         (right-edge . -1)
         (top-edge . 0)
         (bottom-edge . 0)
         (width . 1)
         (class . right-border))        
         
        ((background . ,middle-image)
         (left-edge . 0)
         (right-edge . 0)
         (height . 6)
         (bottom-edge . -6)
         (class . bottom-border))
         
        ((background . ,bevel-image)
         (left-edge . 2)
         (bottom-edge . -6)
         (height . 6)
         (class . bottom-left-corner))
         
        ((background . ,bevel-image)
         (right-edge . 2)
         (bottom-edge . -6)
         (height . 6)
         (class . bottom-right-corner))
         
        ((background . ,left-image)
         (left-edge . -1)
         (bottom-edge . -6)
         (height . 6)
         (class . bottom-left-corner))
                 
        ((background . ,right-image)
         (right-edge . -1)
         (bottom-edge . -6)
         (height . 6)
         (class . bottom-right-corner))         
        
      ))
      
    (shaped-frame `(
        ((background . ,middle-image)
         (left-edge . 0)
         (right-edge . 0)
         (top-edge . -21)
         (class . title))
         
        ((background . ,bevel-image)
         (left-edge . ,20)
         (top-edge . -21)
         (class . title))
         
        ((background . ,bevel-image)
         (right-edge . ,20)
         (top-edge . -21)
         (class . title))
         
        ((background . ,left-title-area)
         (left-edge . ,(lambda (w) (- (title-position w) 8)))
         (top-edge . -19)
         (class . title))
         
        ((background . ,middle-title-area)
         (left-edge . ,(lambda (w) (title-position w)))
         (right-edge . ,(lambda (w) (title-position w)))
         (top-edge . -19)
         (foreground . ,font-colors)
         (text . ,window-name)
         (x-justify . center)
         (y-justify . center)
         (class . title))
         
        ((background . ,right-title-area)
         (right-edge . ,(lambda (w) (- (title-position w) 8)))
         (top-edge . -19)
         (class . title))
                
        ((background . ,close-button-image)
         (left-edge . 4)
         (top-edge . -17)
         (class . close-button))
         
        ((background . ,maximize-button-image)
         (right-edge . 4)
         (top-edge . -17)
         (class . maximize-button))
         
        ((background . ,left-image)
         (left-edge . -1)
         (top-edge . -21)
         (class . title))
                 
        ((background . ,right-image)
         (right-edge . -1)
         (top-edge . -21)
         (class . title))                          
        
      ))

    (transient-frame `(
        ((background . ,middle-image)
         (left-edge . 0)
         (right-edge . 0)
         (top-edge . -21)
         (class . title))
         
        ((background . ,bevel-image)
         (left-edge . ,20)
         (top-edge . -21)
         (class . title))
         
        ((background . ,bevel-image)
         (right-edge . ,20)
         (top-edge . -21)
         (class . title))
         
        ((background . ,left-title-area)
         (left-edge . ,(lambda (w) (- (title-position w) 8)))
         (top-edge . -19)
         (class . title))
         
        ((background . ,middle-title-area)
         (left-edge . ,(lambda (w) (title-position w)))
         (right-edge . ,(lambda (w) (title-position w)))
         (top-edge . -19)
         (foreground . ,font-colors)
         (text . ,window-name)
         (x-justify . center)
         (y-justify . center)
         (class . title))
         
        ((background . ,right-title-area)
         (right-edge . ,(lambda (w) (- (title-position w) 8)))
         (top-edge . -19)
         (class . title))
                
        ((background . ,close-button-image)
         (left-edge . 4)
         (top-edge . -17)
         (class . close-button))
                 
        ((background . ,left-image)
         (left-edge . -1)
         (top-edge . -21)
         (class . title))
                 
        ((background . ,right-image)
         (right-edge . -1)
         (top-edge . -21)
         (class . title))         
                 
        ((background . "Dark Grey")
         (left-edge . -1)
         (top-edge . 0)
         (bottom-edge . 0)
         (width . 1)
         (class . left-border))
         
        ((background . "Dark Grey")
         (right-edge . -1)
         (top-edge . 0)
         (bottom-edge . 0)
         (width . 1)
         (class . right-border))        
         
        ((background . ,middle-image)
         (left-edge . 0)
         (right-edge . 0)
         (height . 6)
         (bottom-edge . -6)
         (class . bottom-border))
         
        ((background . ,bevel-image)
         (left-edge . 2)
         (bottom-edge . -6)
         (height . 6)
         (class . bottom-left-corner))
         
        ((background . ,bevel-image)
         (right-edge . 2)
         (bottom-edge . -6)
         (height . 6)
         (class . bottom-right-corner))
         
        ((background . ,left-image)
         (left-edge . -1)
         (bottom-edge . -6)
         (height . 6)
         (class . bottom-left-corner))
                 
        ((background . ,right-image)
         (right-edge . -1)
         (bottom-edge . -6)
         (height . 6)
         (class . bottom-right-corner))         
        
      ))
      
    (shaped-transient-frame `(
        ((background . ,middle-image)
         (left-edge . 0)
         (right-edge . 0)
         (top-edge . -21)
         (class . title))
         
        ((background . ,bevel-image)
         (left-edge . ,20)
         (top-edge . -21)
         (class . title))
         
        ((background . ,bevel-image)
         (right-edge . ,20)
         (top-edge . -21)
         (class . title))
         
        ((background . ,left-title-area)
         (left-edge . ,(lambda (w) (- (title-position w) 8)))
         (top-edge . -19)
         (class . title))
         
        ((background . ,middle-title-area)
         (left-edge . ,(lambda (w) (title-position w)))
         (right-edge . ,(lambda (w) (title-position w)))
         (top-edge . -19)
         (foreground . ,font-colors)
         (text . ,window-name)
         (x-justify . center)
         (y-justify . center)
         (class . title))
         
        ((background . ,right-title-area)
         (right-edge . ,(lambda (w) (- (title-position w) 8)))
         (top-edge . -19)
         (class . title))
                
        ((background . ,close-button-image)
         (left-edge . 4)
         (top-edge . -17)
         (class . close-button))
                
        ((background . ,left-image)
         (left-edge . -1)
         (top-edge . -21)
         (class . title))
                 
        ((background . ,right-image)
         (right-edge . -1)
         (top-edge . -21)
         (class . title))         
                        
      ))


   )
      
  (add-frame-style 'Chromium
    (lambda (w type)
      (cond 
            ((eq type 'shaped) shaped-frame)
            ((eq type 'unframed) nil-frame)
            ((eq type 'transient) transient-frame)
            ((eq type 'shaped-transient) shaped-transient-frame)
            (t frame))))    
            
  (call-after-property-changed 'WM_NAME update-title-width)        
)
